@@ -223,9 +223,11 @@ CURL *weather_curl_init(CURL * my_curl_handle) {
        curl_easy_setopt(my_curl_handle, CURLOPT_TIMEOUT, 30);
     curl_easy_setopt(my_curl_handle, CURLOPT_CONNECTTIMEOUT, 10);
     /* For disabled cache */
-    headers = curl_slist_append(headers, "Cache-Control: no-cache");
-    headers = curl_slist_append(headers, "Pragma: no-cache");
-    curl_easy_setopt(my_curl_handle, CURLOPT_HTTPHEADER, headers);
+    if (!headers){
+      headers = curl_slist_append(headers, "Cache-Control: no-cache");
+      headers = curl_slist_append(headers, "Pragma: no-cache");
+      curl_easy_setopt(my_curl_handle, CURLOPT_HTTPHEADER, headers);
+    }
 
     config_update_proxy();
     /* Set Proxy option */
@@ -366,10 +368,12 @@ download_html(gpointer data){
         }
         if(app->show_update_window)
             update_window = create_window_update();     /* Window with update information */
+/*
 #ifndef RELEASE
         fprintf(stderr, "\n>>>>>Url - %s, File - %s\n", url,
                 html_file.filename);
 #endif
+*/
         /* Init easy_curl */
         curl_handle = weather_curl_init(curl_handle);
         curl_easy_setopt(curl_handle, CURLOPT_URL, url);
@@ -559,6 +563,7 @@ get_station_url(gchar ** url, struct HtmlFile *html_file,
     gboolean            valid = FALSE;
     static GtkTreeIter  iter;
     gchar               *station_code = NULL,
+                        *new_station_code = NULL,
                         *station_source = NULL;
     gchar                buffer[512];
 #ifdef DEBUGFUNCTIONCALL
@@ -626,9 +631,11 @@ get_station_url(gchar ** url, struct HtmlFile *html_file,
                 *buffer = 0;
                 /* TO DO move this code to sources libs */
                 if (!strcmp(station_source,"gismeteo.ru")){
+                    new_station_code = get_new_gismeteo_code(station_code, station_source);
                     snprintf(buffer, sizeof(buffer) - 1,
                             get_source_detail_url(app->sources_list, station_source),
-                            get_new_gismeteo_code(station_code, station_source));
+                            new_station_code);
+                    g_free(new_station_code);
                 }else
                     snprintf(buffer, sizeof(buffer) - 1,
                             get_source_detail_url(app->sources_list, station_source),
