@@ -22,6 +22,7 @@
  * You should have received a copy of the GNU General Public License
  * along with Maemo Mapper.  If not, see <http://www.gnu.org/licenses/>.
  */
+/*******************************************************************************/
 #ifndef _weather_gpsdistance_h
 #define _weather_gpsdistance_h 1
 /*******************************************************************************/
@@ -29,8 +30,8 @@
 #include <math.h>
 /*******************************************************************************/
 #ifdef ENABLE_GPS
-gdouble
-calculate_distance(gdouble lat1, gdouble lon1, gdouble lat2, gdouble lon2);
+double
+calculate_distance(double lat1, double lon1, double lat2, double lon2);
 #endif
 /*******************************************************************************/
 #endif
